# YAML-lsp

YAML language server for JupyterLab

## Installation

```bash
conda install -c conda-forge jupyterlab jupyterlab-lsp yaml-lsp
```

### Development installation

```bash
conda install -c conda-forge yarn jupyterlab jupyterlab-lsp

git clone https://github.com/martinRenou/yaml-lsp && cd yaml-lsp

cd yaml_lsp && yarn install && cd ..
pip install .
```
